@@ -1,6 +1,5 @@
-from tri_declarative import class_shortcut
-
 from iommi.fragment import Fragment
+from iommi.shortcut import with_defaults
 
 
 class Asset(Fragment):
@@ -17,40 +16,44 @@ class Asset(Fragment):
     """
 
     @classmethod
-    @class_shortcut(
+    @with_defaults(
         tag='script',
     )
-    def js(cls, call_target=None, **kwargs):
+    def js(cls, text=None, **kwargs):
         """
         To use this shortcut, pass `attrs__src='/my_url_to_the.js'`
 
-        Example:
+        Examples:
 
-        .. code:: python
+        .. code-block:: python
 
             Asset.js(
                 attrs__src='https://cdn.jsdelivr.net/npm/select2@4.0.12/dist/js/select2.min.js',
             )
+
+            Asset.js('window.foo = bar')
         """
-        return call_target(**kwargs)
+        return cls(text, **kwargs)
 
     @classmethod
-    @class_shortcut(
+    @with_defaults(
         tag='link',
         attrs__rel='stylesheet',
     )
-    def css(cls, call_target=None, **kwargs):
+    def css(cls, text=None, **kwargs):
         """
         To use this shortcut, pass `attrs__href='/my_url_to_the.js'`
 
-        Example:
+        Examples:
 
-        .. code:: python
+        .. code-block:: python
 
             Asset.css(
                 attrs__href='https://stackpath.bootstrapcdn.com/bootstrap/4.4.1/css/bootstrap.min.css',
                 attrs__integrity='sha384-Vkoo8x4CGsO3+Hhxv8T/Q5PaXtkKtu6ug5TOeNV6gBiFeWPGFN9MuhOf23Q9Ifjh',
                 attrs__crossorigin='anonymous',
             )
+
+            Asset.css('p { font-size: 18pt; }')
         """
-        return call_target(**kwargs)
+        return cls(text, **kwargs)
