@@ -135,7 +135,12 @@ def _generate_tests_from_class_docs(classes):
         return (' ' * levels * 4) + s.strip()
 
     def get_namespace(c):
-        return Namespace({k: getattr(c.__init__, '__iommi_with_defaults_kwargs', {}).get(k) for k, v in items(get_declared(c, 'refinable'))})
+        return Namespace(
+            {
+                k: getattr(c.__init__, '__iommi_with_defaults_kwargs', {}).get(k)
+                for k, v in items(get_declared(c, 'refinable'))
+            }
+        )
 
     for c in classes:
         from io import StringIO
@@ -152,7 +157,9 @@ def _generate_tests_from_class_docs(classes):
             w(indent, underline)
             w(indent, '')
 
-        w(0, '''
+        w(
+            0,
+            '''
 # NOTE: this file is automatically generated
 
 from iommi import *
@@ -169,7 +176,8 @@ request = req('get')
 
 # language=rst
 """
-        ''')
+        ''',
+        )
 
         section(0, c.__name__, indent=0)
 
@@ -242,7 +250,7 @@ request = req('get')
                 v = get_docs_callable_description(v)
 
                 if 'lambda' in v:
-                    v = v[v.find('lambda'):]
+                    v = v[v.find('lambda') :]
                     v = v.strip().strip(',').replace('\n', ' ').replace('  ', ' ')
             if isinstance(v, Part):
                 v = v.bind()
@@ -300,7 +308,9 @@ request = req('get')
                     w(0, '')
                     w(0, '')
 
-                defaults = shortcut if isinstance(shortcut, dict) else getattr(shortcut, '__iommi_with_defaults_kwargs', {})
+                defaults = (
+                    shortcut if isinstance(shortcut, dict) else getattr(shortcut, '__iommi_with_defaults_kwargs', {})
+                )
                 if defaults:
                     defaults = Namespace(defaults)
                     section(3, 'Defaults')
