@@ -44,16 +44,17 @@ class Members(Traversable):
 
 
 def refine_done_members(
-        container,
-        *,
-        name: str,
-        members_from_namespace: Dict[str, Traversable] = None,
-        members_from_declared: Dict[str, Traversable] = None,
-        members_from_auto: Dict[str, Traversable] = None,
-        cls: Type,
-        members_cls: Type = Members,
-        extra_member_defaults=None,
-        unknown_types_fall_through=False):
+    container,
+    *,
+    name: str,
+    members_from_namespace: Dict[str, Traversable] = None,
+    members_from_declared: Dict[str, Traversable] = None,
+    members_from_auto: Dict[str, Traversable] = None,
+    cls: Type,
+    members_cls: Type = Members,
+    extra_member_defaults=None,
+    unknown_types_fall_through=False,
+):
     """
     This function is used to collect and merge data from the constructor
     argument, the declared members, and other config into one data structure.
@@ -75,7 +76,9 @@ def refine_done_members(
     In this example the resulting table will have two columns `instrument` and
     `name`, with `instrument` after name even though it was declared before.
     """
-    forbidden_names = FORBIDDEN_NAMES & (set(keys(members_from_declared or {})) | set(keys(members_from_namespace or {})))
+    forbidden_names = FORBIDDEN_NAMES & (
+        set(keys(members_from_declared or {})) | set(keys(members_from_namespace or {}))
+    )
     if forbidden_names:
         raise ForbiddenNamesException(
             f'The names {", ".join(sorted(forbidden_names))} are reserved by iommi, please pick other names'
@@ -92,7 +95,9 @@ def refine_done_members(
 
     if members_from_declared is not None:
         for key, x in items(members_from_declared):
-            assert '__' not in key, "Don't specify nested attrs using the field name. You lose the ability to include more config from other places. Pick another name and give the path as attr instead"
+            assert (
+                '__' not in key
+            ), "Don't specify nested attrs using the field name. You lose the ability to include more config from other places. Pick another name and give the path as attr instead"
             x._name = key
             member_by_name[key] = x
 
@@ -210,8 +215,7 @@ class MemberBinder(dict):
         except AttributeError as e:
             raise AttributeError(
                 f"'{self.__class__.__name__}' object has no member '{name}'.\n"
-                f"Available members:\n    "
-                + '\n    '.join(sorted(_bindable_names)) + '\n'
+                f"Available members:\n    " + '\n    '.join(sorted(_bindable_names)) + '\n'
             ) from e
 
     def __setattr__(self, name, value):
@@ -244,6 +248,10 @@ class MemberBinder(dict):
         _force_bind_all(self)
         return super().keys()
 
+    def __len__(self):
+        _force_bind_all(self)
+        return super().__len__()
+
     def __repr__(self):
         bound_members = list(dict.keys(self))
         members = [
