@@ -227,7 +227,11 @@ def render_root(*, part, context, **render):
         container=Container(_name='Container').refine_done(parent=part).bind(parent=part),
         content=content,
         title=title if title not in (None, MISSING) else '',
-        iommi_debug_panel=iommi_debug_panel(part) if iommi_debug_on() and '_iommi_disable_debug_panel' not in part.get_request().GET else '',
+        iommi_debug_panel=(
+            iommi_debug_panel(part)
+            if iommi_debug_on() and '_iommi_disable_debug_panel' not in part.get_request().GET
+            else ''
+        ),
         assets=assets,
         **(part.context if isinstance(part, Page) else {}),
         **context,
