@@ -59,7 +59,10 @@ from iommi.declarative.namespace import (
 )
 from iommi.declarative.with_meta import with_meta
 from iommi.endpoint import path_join
-from iommi.evaluate import evaluate
+from iommi.evaluate import (
+    evaluate,
+    evaluate_strict,
+)
 from iommi.form import (
     bool_parse,
     boolean_tristate__parse,
@@ -242,7 +245,6 @@ class Filter(Part):
         attr=MISSING,
         search_fields=MISSING,
         field__required=False,
-
         is_valid_filter=default_filter__is_valid_filter,
         query_name=lambda filter, **_: filter.iommi_name(),
     )
@@ -257,7 +259,9 @@ class Filter(Part):
 
     def on_refine_done(self):
         if 'choice' in getattr(self, 'iommi_shortcut_stack', []):
-            assert self.iommi_namespace.get('choices') is not None, 'To use Filter.choice, you must pass the choices list'
+            assert (
+                self.iommi_namespace.get('choices') is not None
+            ), 'To use Filter.choice, you must pass the choices list'
 
         model_field = self.model_field
         if model_field and model_field.remote_field:
@@ -655,7 +659,14 @@ class Query(Part):
         self.query_advanced_value = None
         self.query_error = None
 
-        refine_done_members(self, name='filters', members_from_namespace=self.filters, members_from_declared=self.get_declared('_filters_dict'), members_from_auto=filters_from_auto, cls=self.get_meta().member_class)
+        refine_done_members(
+            self,
+            name='filters',
+            members_from_namespace=self.filters,
+            members_from_declared=self.get_declared('_filters_dict'),
+            members_from_auto=filters_from_auto,
+            cls=self.get_meta().member_class,
+        )
 
         self._on_refine_done_form()
 
@@ -700,15 +711,24 @@ class Query(Part):
             )
 
         for name, filter in items(self.iommi_namespace.filters):
+            _orig_include = getattr_path(filter, 'field__include', not filter.freetext)
             declared_fields[name] = setdefaults_path(
-                Namespace(),
+                Namespace(
+                    include=(
+                        lambda query, field, _orig_include=_orig_include, **_: (
+                            field.iommi_name() in query.filters
+                            and evaluate_strict(_orig_include, **query.iommi_evaluate_parameters())
+                        )
+                    )
+                    if getattr(filter, 'include', None) is not False
+                    else False,
+                ),
                 filter.field,
                 _name=name,
                 call_target__cls=field_class,
                 model_field=filter.model_field,
                 attr=name if filter.attr is MISSING else filter.attr,
                 help__include=False,
-                include=lambda query, field, **_: field.iommi_name() in query.filters and not query.filters[field.iommi_name()].freetext,
             )
 
         # Remove fields from the form that correspond to non-included filters
@@ -723,17 +743,23 @@ class Query(Part):
         form_args = self.form
 
         # noinspection PyCallingNonCallable
-        self.form: Form = self.get_meta().form_class(**setdefaults_path(
-            Namespace(),
-            form_args,
-            _name='form',
-            fields=declared_fields,
-            attrs__method='get',
-            actions__submit=dict(
-                attrs={'data-iommi-filter-button': ''},
-                display_name=gettext('Filter'),
-            ),
-        )).refine_done(parent=self)
+        self.form: Form = (
+            self.get_meta()
+            .form_class(
+                **setdefaults_path(
+                    Namespace(),
+                    form_args,
+                    _name='form',
+                    fields=declared_fields,
+                    attrs__method='get',
+                    actions__submit=dict(
+                        attrs={'data-iommi-filter-button': ''},
+                        display_name=gettext('Filter'),
+                    ),
+                )
+            )
+            .refine_done(parent=self)
+        )
 
     def on_bind(self) -> None:
         # Prevent the nested form from thinking it's a part of a nested form set up
@@ -768,7 +794,7 @@ class Query(Part):
             if q:
                 rows = rows.filter(q)
 
-        return query.postprocess(rows=rows, **query.iommi_evaluate_parameters())
+        return query.invoke_callback(query.postprocess, rows=rows)
 
     @staticmethod
     @refinable
@@ -1040,7 +1066,8 @@ class Query(Part):
     @dispatch()
     def filters_from_model(cls, **kwargs):
         return create_members_from_model(
-            member_class=cls.get_meta().member_class, **kwargs
+            member_class=cls.get_meta().member_class,
+            **kwargs,
         )
 
     @classmethod
