@@ -64,7 +64,6 @@ bootstrap_base = Style(
                 input__attrs__class={'form-check-input': True, 'form-control': False},
                 attrs__class={'form-check': True},
                 label__attrs__class={'form-check-label': True},
-                template='iommi/form/bootstrap/row_checkbox.html',
             ),
             radio=dict(
                 attrs__class={
@@ -88,7 +87,6 @@ bootstrap_base = Style(
             'form-text': True,
             'text-muted': True,
         },
-        non_editable_input__attrs__class={'form-control': False},
     ),
     FieldGroup=dict(
         tag='div',
