@@ -1,10 +1,14 @@
 from iommi.style import Style
-from iommi.style_base import base
+from iommi.style_base import (
+    base,
+    select2_enhanced_forms,
+)
 from iommi.style_font_awesome_4 import font_awesome_4
 
 test = Style(
     base,
     font_awesome_4,
+    select2_enhanced_forms,
     internal=True,
     root__assets=dict(
         jquery=None,
@@ -16,6 +20,10 @@ test = Style(
     Field=dict(
         shortcuts=dict(),
     ),
+    FieldGroup=dict(
+        tag='div',
+        attrs__class__form_group=True,
+    ),
     Table=dict(
         attrs__class__table=True,
     ),
