@@ -5,8 +5,6 @@ from typing import (
     List,
 )
 
-from iommi.struct import Struct
-
 from iommi.attrs import evaluate_attrs
 from iommi.base import (
     items,
@@ -17,8 +15,11 @@ from iommi.evaluate import (
     evaluate_members,
     evaluate_strict,
     evaluate_strict_container,
+    get_callable_description,
+    get_signature,
+    matches,
+    signature_from_kwargs,
 )
-from iommi.path import decode_path_components
 from iommi.refinable import (
     evaluated_refinable,
     EvaluatedRefinable,
@@ -28,6 +29,7 @@ from iommi.refinable import (
     RefinableMembers,
     RefinableObject,
 )
+from iommi.struct import Struct
 from iommi.style import Style
 
 # Backward compatible definition
@@ -101,6 +103,9 @@ class Traversable(RefinableObject):
         if hasattr(self, '_iommi_path_override'):
             return self._iommi_path_override
 
+        if hasattr(self, '_iommi_path_cache'):
+            return self._iommi_path_cache
+
         long_path = build_long_path(self)
         path_by_long_path = get_path_by_long_path(self)
         path = path_by_long_path.get(long_path)
@@ -166,7 +171,7 @@ class Traversable(RefinableObject):
         if parent is None:
             evaluate_parameters['request'] = request
             if hasattr(request, 'iommi_view_params'):
-                evaluate_parameters['params'] = Struct(decode_path_components(request, **request.iommi_view_params))
+                evaluate_parameters['params'] = request.iommi_view_params
         result._evaluate_parameters = evaluate_parameters
 
         if hasattr(result, 'include'):
@@ -185,9 +190,7 @@ class Traversable(RefinableObject):
         if hasattr(result, 'attrs'):
             result.attrs = evaluate_attrs(result, **result.iommi_evaluate_parameters())
 
-        evaluated_attributes = [
-            k for k, v in items(result.get_declared('refinable')) if is_evaluated_refinable(v)
-        ]
+        evaluated_attributes = [k for k, v in items(result.get_declared('refinable')) if is_evaluated_refinable(v)]
         evaluate_members(result, evaluated_attributes, **evaluate_parameters)
 
         if hasattr(result, 'extra_evaluated'):
@@ -204,6 +207,21 @@ class Traversable(RefinableObject):
     def iommi_evaluate_parameters(self):
         return self._evaluate_parameters
 
+    def invoke_callback(self, callback, **kwargs):
+        try:
+            return callback(**kwargs, **self.iommi_evaluate_parameters())
+        except TypeError as e:
+            if not matches(
+                signature_from_kwargs(dict(**kwargs, **self.iommi_evaluate_parameters())),
+                get_signature(callback),
+                __match_empty=True,
+            ):
+                raise TypeError(
+                    f'TypeError when invoking callback {get_callable_description(callback)}.\n'
+                    f'(Keyword arguments: {", ".join(sorted([*kwargs, *self.iommi_evaluate_parameters()]))})'
+                ) from e
+            raise
+
     def get_request(self):
         if self._parent is None:
             return self._request
@@ -226,7 +244,9 @@ def declared_members(node: Traversable) -> Any:
         else:
             child = getattr(node, k)
             if isinstance(child, RefinableObject):
-                assert child.is_refine_done, f"refine_done() not invoked on something ({k}) in the declared namespace of {node._name}"
+                assert (
+                    child.is_refine_done
+                ), f"refine_done() not invoked on something ({k}) in the declared namespace of {node._name}"
                 result[k] = child
     if hasattr(node, '_declared_members'):
         result.update(node._declared_members)
@@ -281,16 +301,17 @@ def build_long_path_by_path(root) -> Dict[str, str]:
 
             long_path = '/'.join(long_path_segments)
             short_path = find_unique_suffix(short_path_candidate_segments)
-            if short_path is not None:
-                result[short_path] = long_path
-            else:
+            if short_path is None:
                 less_short_path = find_unique_suffix(long_path_segments)
                 assert less_short_path is not None, (
                     f"Ran out of names...\n"
                     f"Any suitable short name for {'/'.join(long_path_segments)} already taken.\n\n"
                     f"Result so far:\n" + '\n'.join(f'{k}   ->   {v}' for k, v in result.items())
                 )
-                result[less_short_path] = long_path
+                short_path = less_short_path
+            result[short_path] = long_path
+
+            node._iommi_path_cache = short_path
 
         if isinstance(node, RefinableObject):
             members = declared_members(node)
